%  predpr3.m
% Matlab file for Part 3 of the Preditor-Prey Models module

disp('********************************************')
disp('Part 3:  Euler''s Method for Systems')
disp('********************************************')
disp('  ')    

    format short

    disp('Step 1:')
    disp('We repeat one of our earlier calculations')
    disp('of a trajectory in the xy-plane, but')
    disp('using Euler''s Method instead of the')
    disp('built-in MATLAB solver ode23. ')
    disp(' ')
    disp('MATLAB doesn''t have Euler''s Method') 
    disp('built in, so we need to write it')
    disp('ourselves.  We''ll generate values')
    disp('of x(t) and y(t) at 40 equally')
    disp('spaced time values between 0 and 10.')
    disp(' ')
    disp('--------------------------------------------')
    disp('Enter MATLAB commands to make ')
    disp('n=40, Delta=10/n, x0=20, and y0=20.')
    disp(' ')
    disp('To continue afterwards, type the word return')
    disp('and hit enter!')
    disp(' ')

    keyboard;
    disp(' ')

    disp('--------------------------------------------')
    disp('Step 1 (cont.):')
    disp('First let''s define equally spaced time values:')
    disp('Copy the following commands and paste them as')
    disp('a group at a MATLAB prompt, then execute them.')
    disp(' ')
    disp('     for k=1:n+1 ')
    disp('        t(k)=(k-1)*Delta; ')
    disp('     end ')
    disp(' ')
    disp('To check, type the variable name: t, which')
    disp('should give the times from 0 to 10 in')
    disp('steps of Delta=0.25 seconds.')
    disp(' ')
    disp('To continue afterwards, type the word return')
    disp('and hit enter!')
    disp(' ')

    keyboard;
    disp(' ')

    disp('----------------------------------------------')
    disp('Step 1 (cont.):')  
    disp('Subscripts in MATLAB cannot start at zero.')
    disp('Thus, we need to initialize x(1) and y(1)')
    disp(' to be the initial values x0 and y0.')
    disp('Enter the commands: ')
    disp('    x(1)=x0;   ')
    disp('    y(1)=y0;  ')
    disp(' ')
    disp('To continue afterwards, type the word return')
    disp('and hit enter!')
    disp(' ')

    keyboard;    
    disp(' ')

    disp('-----------------------------------------------')
    disp('Step 1 (cont.):')
    disp('Now we can put our recursive definition for x(k)')
    disp('and y(k) into a loop to compute x(2), y(2),')
    disp('then x(3),y(3) etc.  The trick is to use')
    disp('rise=slope*run where the x slope and y slope') 
    disp('are provided by the function de_rhs. ')
    disp(' ')
    disp('Copy the following commands and paste them as')
    disp('a group at a MATLAB prompt, then execute them.')
    disp(' ')
    disp('   for k=2:n+1 ')
    disp('      zprime=de_rhs(t(k-1),[x(k-1),y(k-1)]'');')
    disp('      x(k)=x(k-1)+zprime(1)*Delta; ')
    disp('      y(k)=y(k-1)+zprime(2)*Delta; ')
    disp('   end ')
    disp(' ')
    disp('To check, type the variable name: x, which')
    disp('should give the x values for each time in')
    disp('vector t.  Likewise, type: y for the y values.')
    disp(' ')
    disp('To continue afterwards, type the word return')
    disp('and hit enter!')
    disp(' ')
    
    keyboard;
    disp(' ')

    disp('------------------------------------------------')
    disp('Step 1 (cont.):')
    disp('Let''s look at a plot of the (x,y) pairs.')
    disp('We will plot the (x,y) pairs using the')
    disp('little-o plot symbol in red.')
    disp('We will redo our slope field plot so that,')
    disp('our plot will be on top of the slope field.')
    disp(' ')
    disp('Copy each of the following commands and')
    disp('paste them as a group at a MATLAB prompt')
    disp('to execute them.')
    disp(' ')
    disp('     clf ')
    disp('     dirfield(0,140,0,80) ')
    disp('     hold on ')
    disp('     plot(x,y,''ro'')      ')
    disp(' ')
    disp('------------------------------------------------')  
    disp('Enter your answers to the questions in step 1')
    disp('as MATLAB comments in your diary file.')
    disp(' ') 
    disp('To continue afterwards, type the word return')
    disp('and hit enter!')
    disp(' ')
    
    keyboard;
    disp(' ')

    disp('------------------------------------------------')
    disp('Step 2: ')
    disp('To change the step size, enter the new values:' )
    disp('Delta=0.1 and n=10/Delta. ')
    disp('  ')
    disp('------------------------------------------------')
    disp('Redo the steps of Euler''s Method for the new')
    disp('step size and plot the new Euler solution on')
    disp('top of the slope field.')
    disp(' ')   
    disp('To continue afterwards, type the word return')
    disp('and hit enter!')
    disp(' ')

    keyboard;
    disp(' ')

    disp('------------------------------------------------')
    disp('Step 2 (cont.): ')   
    disp('Enter your answers to the questions in step 2')
    disp('as MATLAB comments in your diary file.')
    disp(' ') 
    disp(' ') 
    disp('When your answers are done, to go on to')
    disp('part 4 of this module, type: predpr4')
    disp(' ')